"""Translate an image to another image
An example of command-line usage is:
python export_graph.py --model pretrained/apple2orange.pb \
                       --input input_sample.jpg \
                       --output output_sample.jpg \
                       --image_size 256
"""
import time

import cv2
import numpy as np
import tensorflow as tf

FLAGS = tf.flags.FLAGS

tf.flags.DEFINE_string('model', './output_model/model_sup.pb', 'model path (.pb)')
tf.flags.DEFINE_string('input_folder', './paper_images/', 'input image path (.jpg)')
tf.flags.DEFINE_string('output_folder', './output_images/', 'output image path (.jpg)')
tf.flags.DEFINE_integer('image_size', '321', 'image size, default: 256')


def load_graph(frozen_graph_filename):
    # We load the protobuf file from the disk and parse it to retrieve the
    # unserialized graph_def
    with tf.gfile.GFile(frozen_graph_filename, "rb") as f:
        graph_def = tf.GraphDef()
        graph_def.ParseFromString(f.read())

    # Then, we import the graph_def into a new Graph and returns it
    with tf.Graph().as_default() as graph:
        # The name var will prefix every op/nodes in your graph
        # Since we load everything in a new graph, this is not needed
        tf.import_graph_def(graph_def, name="prefix")
    return graph

def main(unused_argv):
    # cv2.namedWindow("preview")
    vc = cv2.VideoCapture(0)

    if vc.isOpened():  # try to get the first frame
        rval, frame = vc.read()
    else:
        rval = False
    graph = load_graph(FLAGS.model)
    input_image = graph.get_tensor_by_name('prefix/input_image:0')
    output_image = graph.get_tensor_by_name('prefix/output_image:0')
    # inference
    with tf.Session(graph=graph) as sess:
        while rval:
            start_time = time.time()
            frame = cv2.resize(frame, (FLAGS.image_size, FLAGS.image_size))
            img_as_string = cv2.imencode('.jpg', frame)[1].tostring()


            generated = output_image.eval(feed_dict={input_image: img_as_string})
            output = cv2.imdecode(np.frombuffer(generated, np.uint8), -1)
            output = np.hstack((frame, output))
            cv2.imshow('Image', output)

            rval, frame = vc.read()
            key = cv2.waitKey(20)
            print("%d s" % (time.time() - start_time))
            if key == 27:  # exit on ESC
                break
    vc.release()
    cv2.destroyWindow("preview")


if __name__ == '__main__':
    tf.app.run()
