from shutil import copyfile

import tensorflow as tf

try:
    from os import scandir
except ImportError:
    # Python 2 polyfill module
    from scandir import scandir

FLAGS = tf.flags.FLAGS

tf.flags.DEFINE_string('data_dir', '../../../data/VOC2012/', 'data directory')
tf.flags.DEFINE_string('data_list', '../../../data/val.txt', 'data_list')
tf.flags.DEFINE_string('output_dir', '../val_labels/', 'output directory')

def read_labeled_image_list(data_dir, data_list):
    """
    Reads txt file containing paths to images and ground truth masks

    :param data_dir: path to the directory with images and masks
    :param data_list: path to the file with lines are the number of images
    :return: two lists with all file names for images and masks, respectively
    """
    f = open(data_list, 'r')
    images = []
    masks = []
    for line in f:
        try:
            image, mask = line.strip("\n").split(' ')
        except ValueError:  # Adhoc for test.
            image = mask = line.strip("\n")
        images.append(data_dir + image)
        masks.append(data_dir + mask)
    return images, masks


def main(unused_argv):
    images, labels = read_labeled_image_list(FLAGS.data_dir, FLAGS.data_list)
    for i in range(len(images)):
        image = images[i][images[i].rfind('/') + 1:]
        label = labels[i][labels[i].rfind('/') + 1:]
        copyfile(FLAGS.data_dir + 'SegmentationClass/' + label, FLAGS.output_dir + label)
        print('Copied file {} of {}.'.format(i + 1, len(images)))


if __name__ == '__main__':
    tf.app.run()
